##########################
User Guide
##########################

This user guide shows the basics on how to get started with using ADAM. In this guide,
we show how to load and preprocess the radar data to be ready for inference by ADAM.
Finally, we will demonstrate how to process a batch of radar files.

.. toctree::
   :maxdepth: 3

   overview.rst
   read_radar_data.rst
   show_me_the_lakebreeze.rst